==> Gambio v4.1.2.0.zip: Vollversion GX v4.1.2.0/Shopsystem/Dateien/lang/german/original_sections/modules/shipping/zones.lang.inc.php <==
<?php
/* --------------------------------------------------------------
	zones.lang.inc.php 2015-01-02 gm
	Gambio GmbH
	http://www.gambio.de
	Copyright (c) 2015 Gambio GmbH
	Released under the GNU General Public License (Version 2)
	[http://www.gnu.org/licenses/gpl-2.0.html]
   --------------------------------------------------------------
*/

$t_language_text_section_content_array = array
(
	'HEADING_SUB_TITLE' => 'Länder / Steuern',
	'HEADING_TITLE' => 'Bundesländer',
	'HEADING_WARNING' => 'Änderungen in diesem Bereich können dazu führen, dass der Shop fehlerhaft arbeitet. In der Regel sind die Einstellungen in diesem Bereich bereits standardmäßig korrekt und es ist  keine Bearbeitung notwendig. Bitte führen Sie nur Änderungen durch, wenn Sie sich über die Folgen im Klaren sind!',
	'TABLE_HEADING_ACTION' => 'Aktion',
	'TABLE_HEADING_COUNTRY_NAME' => 'Land',
	'TABLE_HEADING_ZONE_CODE' => 'Code',
	'TABLE_HEADING_ZONE_NAME' => 'Bundesland',
	'TEXT_INFO_COUNTRY_NAME' => 'Land:',
	'TEXT_INFO_DELETE_INTRO' => 'Sind Sie sicher, dass Sie dieses Bundesland löschen wollen?',
	'TEXT_INFO_EDIT_INTRO' => 'Bitte füllen Sie alle Felder aus.',
	'TEXT_INFO_HEADING_DELETE_ZONE' => 'Bundesland löschen',
	'TEXT_INFO_HEADING_EDIT_ZONE' => 'Bundesland bearbeiten',
	'TEXT_INFO_HEADING_NEW_ZONE' => 'Neues Bundesland',
	'TEXT_INFO_INSERT_INTRO' => 'Bitte geben Sie das neue Bundesland mit allen relevanten Daten ein.',
	'TEXT_INFO_ZONES_CODE' => 'Code des Bundeslandes:',
	'TEXT_INFO_ZONES_NAME' => 'Name des Bundeslandes:'
);

==> Gambio v4.5.2.2.zip: Vollversion GX v4.5.2.2/Shopsystem/Dateien/lang/german/original_sections/modules/shipping/zones.lang.inc.php <==
<?php
/* --------------------------------------------------------------
	zones.lang.inc.php 2015-01-02 gm
	Gambio GmbH
	http://www.gambio.de
	Copyright (c) 2015 Gambio GmbH
	Released under the GNU General Public License (Version 2)
	[http://www.gnu.org/licenses/gpl-2.0.html]
   --------------------------------------------------------------
*/

$t_language_text_section_content_array = array
(
	'HEADING_SUB_TITLE' => 'Länder / Steuern',
	'HEADING_TITLE' => 'Bundesländer',
	'HEADING_WARNING' => 'Änderungen in diesem Bereich können dazu führen, dass der Shop fehlerhaft arbeitet. In der Regel sind die Einstellungen in diesem Bereich bereits standardmäßig korrekt und es ist keine Bearbeitung notwendig. Bitte führe nur Änderungen durch, wenn du dir über die Folgen im Klaren bist!',
	'TABLE_HEADING_ACTION' => 'Aktion',
	'TABLE_HEADING_COUNTRY_NAME' => 'Land',
	'TABLE_HEADING_ZONE_CODE' => 'Code',
	'TABLE_HEADING_ZONE_NAME' => 'Bundesland',
	'TEXT_INFO_COUNTRY_NAME' => 'Land:',
	'TEXT_INFO_DELETE_INTRO' => 'Bist du sicher, dass du dieses Bundesland löschen willst?',
	'TEXT_INFO_EDIT_INTRO' => 'Bitte fülle alle Felder aus.',
	'TEXT_INFO_HEADING_DELETE_ZONE' => 'Bundesland löschen',
	'TEXT_INFO_HEADING_EDIT_ZONE' => 'Bundesland bearbeiten',
	'TEXT_INFO_HEADING_NEW_ZONE' => 'Neues Bundesland',
	'TEXT_INFO_INSERT_INTRO' => 'Bitte gib das neue Bundesland mit allen relevanten Daten ein.',
	'TEXT_INFO_ZONES_CODE' => 'Code des Bundeslandes:',
	'TEXT_INFO_ZONES_NAME' => 'Name des Bundeslandes:'
);
